@@ -101,11 +101,11 @@ class SingleSensorContext(AlgoConfigBase):
         default=None
     )
     reference_temperature: Optional[int] = attrs.field(default=None)
-
+    sensor_calibration: Optional[a121.SensorCalibration] = attrs.field(default=None)
     # TODO: Make recorded_thresholds Optional[List[Optional[npt.NDArray[np.float_]]]]
 
     def to_h5(self, group: h5py.Group) -> None:
-        for k, v in attrs.asdict(self).items():
+        for k, v in attrs.asdict(self, recurse=False).items():
             if k in [
                 "recorded_thresholds_mean_sweep",
                 "recorded_thresholds_noise_std",
@@ -118,10 +118,15 @@ class SingleSensorContext(AlgoConfigBase):
 
             if isinstance(v, a121.SessionConfig):
                 _create_h5_string_dataset(group, k, v.to_json())
+            elif isinstance(v, a121.SensorCalibration):
+                sensor_calibration_group = group.create_group("sensor_calibration")
+                v.to_h5(sensor_calibration_group)
             elif isinstance(v, np.ndarray) or isinstance(v, float) or isinstance(v, int):
                 group.create_dataset(k, data=v, track_times=False)
             else:
-                raise RuntimeError(f"Unexpected {type(self).__name__} field type '{type(v)}'")
+                raise RuntimeError(
+                    f"Unexpected {type(self).__name__} field '{k}' of type '{type(v)}'"
+                )
 
         if self.recorded_thresholds_mean_sweep is not None:
             recorded_thresholds_mean_sweep_group = group.create_group(
@@ -182,6 +187,11 @@ class SingleSensorContext(AlgoConfigBase):
             bg_noise_std = _get_group_items(group["bg_noise_std"])
             context_dict["bg_noise_std"] = bg_noise_std
 
+        if "sensor_calibration" in group:
+            context_dict["sensor_calibration"] = a121.SensorCalibration.from_h5(
+                group["sensor_calibration"]
+            )
+
         return SingleSensorContext(**context_dict)
 
 
@@ -266,7 +276,7 @@ class Detector:
 
     session_config: a121.SessionConfig
     processor_specs: List[ProcessorSpec]
-    multi_sensor_context: DetectorContext
+    context: DetectorContext
 
     def __init__(
         self,
@@ -282,13 +292,13 @@ class Detector:
         self.started = False
 
         if context is None or not bool(context.single_sensor_contexts):
-            self.multi_sensor_context = DetectorContext(
+            self.context = DetectorContext(
                 single_sensor_contexts={
                     sensor_id: SingleSensorContext() for sensor_id in self.sensor_ids
                 }
             )
         else:
-            self.multi_sensor_context = context
+            self.context = context
 
         self.aggregator: Optional[Aggregator] = None
 
@@ -319,7 +329,7 @@ class Detector:
         ) or self._has_recorded_threshold_mode(self.detector_config, self.sensor_ids):
             self._record_threshold()
 
-        for context in self.multi_sensor_context.single_sensor_contexts.values():
+        for context in self.context.single_sensor_contexts.values():
             context.session_config_used_during_calibration = self.session_config
 
     def _calibrate_close_range(self) -> None:
@@ -353,7 +363,7 @@ class Detector:
         assert isinstance(extended_result, list)
         self.client.stop_session()
 
-        for sensor_id, context in self.multi_sensor_context.single_sensor_contexts.items():
+        for sensor_id, context in self.context.single_sensor_contexts.items():
             aggregator_result = aggregators[sensor_id].process(extended_result=extended_result)
             (processor_result,) = aggregator_result.processor_results
             assert processor_result.phase_jitter_comp_reference is not None
@@ -363,6 +373,8 @@ class Detector:
             context.recorded_thresholds_mean_sweep = None
             context.recorded_thresholds_noise_std = None
 
+            context.sensor_calibration = self.client.calibrations[sensor_id]
+
     def _record_threshold(self) -> None:
         """Calibrates the parameters used when forming the recorded threshold."""
 
@@ -400,7 +412,7 @@ class Detector:
 
         assert isinstance(extended_result, list)
 
-        for sensor_id, context in self.multi_sensor_context.single_sensor_contexts.items():
+        for sensor_id, context in self.context.single_sensor_contexts.items():
             recorded_thresholds_mean_sweep = []
             recorded_thresholds_noise_std = []
             for processor_result in aggregators_result[sensor_id].processor_results:
@@ -451,7 +463,7 @@ class Detector:
         assert isinstance(extended_result, list)
         self.client.stop_session()
 
-        for sensor_id, context in self.multi_sensor_context.single_sensor_contexts.items():
+        for sensor_id, context in self.context.single_sensor_contexts.items():
             bg_noise_one_sensor = []
             for spec in self.processor_specs:
                 result = extended_result[spec.group_index][sensor_id]
@@ -492,11 +504,19 @@ class Detector:
 
         assert isinstance(extended_result, list)
 
-        for sensor_id, context in self.multi_sensor_context.single_sensor_contexts.items():
+        for sensor_id, context in self.context.single_sensor_contexts.items():
             context.loopback_peak_location_m = calculate_loopback_peak_location(
                 extended_result[0][sensor_id], sensor_config
             )
 
+    @staticmethod
+    def _get_sensor_calibrations(context: DetectorContext) -> dict[int, a121.SensorCalibration]:
+        return {
+            sensor_id: single_context.sensor_calibration
+            for sensor_id, single_context in context.single_sensor_contexts.items()
+            if single_context.sensor_calibration is not None
+        }
+
     @classmethod
     def get_detector_status(
         cls,
@@ -560,17 +580,17 @@ class Detector:
         return cls.MIN_DIST_M <= config.start_m and config.end_m <= cls.MAX_DIST_M
 
     @staticmethod
-    def _close_range_calibrated(multi_sensor_context: DetectorContext) -> bool:
+    def _close_range_calibrated(context: DetectorContext) -> bool:
         has_dl = np.all(
             [
                 context.direct_leakage is not None
-                for context in multi_sensor_context.single_sensor_contexts.values()
+                for context in context.single_sensor_contexts.values()
             ]
         )
         has_pjcr = np.all(
             [
                 context.phase_jitter_comp_reference is not None
-                for context in multi_sensor_context.single_sensor_contexts.values()
+                for context in context.single_sensor_contexts.values()
             ]
         )
 
@@ -580,18 +600,18 @@ class Detector:
         return bool(has_dl and has_pjcr)
 
     @staticmethod
-    def _recorded_threshold_calibrated(multi_sensor_context: DetectorContext) -> bool:
+    def _recorded_threshold_calibrated(context: DetectorContext) -> bool:
         mean_sweep_calibrated = np.all(
             [
                 context.recorded_thresholds_mean_sweep is not None
-                for context in multi_sensor_context.single_sensor_contexts.values()
+                for context in context.single_sensor_contexts.values()
             ]
         )
 
         std_calibrated = np.all(
             [
                 context.recorded_thresholds_noise_std is not None
-                for context in multi_sensor_context.single_sensor_contexts.values()
+                for context in context.single_sensor_contexts.values()
             ]
         )
 
@@ -617,27 +637,29 @@ class Detector:
             spec.processor_config.threshold_method for spec in processor_specs
         ]
 
-    def start(
-        self, recorder: Optional[a121.Recorder] = None, skip_calibration: bool = False
-    ) -> None:
+    def start(self, recorder: Optional[a121.Recorder] = None) -> None:
         """Method for setting up measurement session."""
 
         if self.started:
             raise RuntimeError("Already started")
 
-        status = self.get_detector_status(
-            self.detector_config, self.multi_sensor_context, self.sensor_ids
-        )
+        status = self.get_detector_status(self.detector_config, self.context, self.sensor_ids)
 
         if not status.ready_to_start:
             raise RuntimeError(f"Not ready to start ({status.detector_state.name})")
         specs = self._add_context_to_processor_spec(self.processor_specs)
-        extended_metadata = self.client.setup_session(self.session_config)
+
+        sensor_calibration = self._get_sensor_calibrations(self.context)
+
+        extended_metadata = self.client.setup_session(
+            self.session_config, calibrations=sensor_calibration
+        )
+
         assert isinstance(extended_metadata, list)
         assert np.all(
             [
                 context.loopback_peak_location_m is not None
-                for context in self.multi_sensor_context.single_sensor_contexts.values()
+                for context in self.context.single_sensor_contexts.values()
             ]
         )
         aggregator_config = AggregatorConfig(
@@ -661,7 +683,7 @@ class Detector:
                     algo_group,
                     self.sensor_ids,
                     self.detector_config,
-                    self.multi_sensor_context,
+                    self.context,
                 )
             else:
                 # Should never happen as we currently only have the H5Recorder
@@ -1167,7 +1189,7 @@ class Detector:
         """
 
         updated_specs_all_sensors = {}
-        for sensor_id, context in self.multi_sensor_context.single_sensor_contexts.items():
+        for sensor_id, context in self.context.single_sensor_contexts.items():
             assert context.bg_noise_std is not None
             updated_specs: List[ProcessorSpec] = []
             for idx, (spec, bg_noise_std) in enumerate(zip(processor_specs, context.bg_noise_std)):
