@@ -9,9 +9,17 @@ from ._enums import (
     PluginState,
 )
 from ._exceptions import HandledException
+from ._version_checker import check_package_outdated, get_latest_changelog
 from .app import main
 from .app_model import AppModel
-from .backend import BackendPlugin, GeneralMessage, Message, PluginStateMessage, is_task
+from .backend import (
+    BackendLogger,
+    BackendPlugin,
+    GeneralMessage,
+    Message,
+    PluginStateMessage,
+    is_task,
+)
 from .pluginbase import PlotPluginBase, PluginSpecBase, ViewPluginBase
 from .storage import get_temp_dir, get_temp_h5_path
 from .ui import BUTTON_ICON_COLOR
